@@ -697,7 +697,7 @@ and generate_call ?(newcall=false) ctx v vl =
 		let nargs = List.length l in
 		push ctx [VInt nargs];
 		write ctx AFSCommand2;
-		ctx.stack <- ctx.stack - (nargs - 1)
+		ctx.stack <- ctx.stack - nargs
 	| EConst (Ident "fscommand") , [v] ->
 		push ctx [VStr "FSCommand:"];
 		generate_val ctx v;
@@ -732,6 +732,8 @@ and generate_call ?(newcall=false) ctx v vl =
 	| EConst (Ident "getVersion") , _ ->
 		push ctx [VStr "/:$version"];
 		write ctx AEval;
+	| EConst (Ident "stopAllSounds"), [] ->
+		write ctx AStopSounds
 	| _ , _ ->
 		let nargs = List.length vl in
 		List.iter (generate_val ctx) (List.rev vl);
