@@ -557,7 +557,7 @@ let rec resolve_package ctx v (p : string list) pos =
 and type_field ctx t f p =
 	match resolve t f with
 	| None -> 
-		if not (is_dynamic t) then error (Custom (s_type_decl (match t with Static c -> Class c | _ -> t) ^ " have no " ^ (match t with Static _ -> "static " | _ -> "") ^ "field " ^ f)) p;
+		if not (is_dynamic t) then error (Custom (s_type_decl (match t with Static c -> Class c | _ -> t) ^ " has no " ^ (match t with Static _ -> "static " | _ -> "") ^ "field " ^ f)) p;
 		Dyn
 	| Some f ->
 		if f.f_public = IsPrivate then (match t with
@@ -736,7 +736,7 @@ and type_val ?(in_field=false) ctx ((v,p) as e) =
 let rec type_expr ctx (e,p) =
 	match e with
 	| EVars (_,_,vl) ->
-		let vt = List.map (fun (name,tt,v) -> 
+		List.iter (fun (name,tt,v) -> 
 			let t = (if !local_inference && v <> None && tt = None then Dyn else t_opt ctx p tt) in
 			let t = (match v with
 				| None -> t 
@@ -745,9 +745,8 @@ let rec type_expr ctx (e,p) =
 					unify_array tv t v (pos v);
 					if !local_inference && tt = None then tv else t
 			) in
-			name , t
-		) vl in
-		List.iter (fun (name,t) -> define_local ctx name t p) vt
+			define_local ctx name t p			
+		) vl
 	| EFunction f ->
 		assert false
 	| EBlock el ->
@@ -839,7 +838,7 @@ let type_function ?(lambda=false) ctx clctx f p =
 		if not lambda then verbose_msg ("Typing " ^ s_type_path clctx.path ^ "." ^ f.fname);
 		let ctx = {
 			ctx with
-				current = if lambda then { clctx with imports = ctx.current.imports } else clctx;
+				current = if lambda then { clctx with imports = ctx.current.imports; native = false; } else clctx;
 				locals = if lambda then ctx.locals else Hashtbl.create 0;
 				in_static = (f.fstatic = IsStatic);
 				in_constructor = (f.fstatic = IsMember && f.fname = clctx.name);
@@ -878,6 +877,7 @@ let rec type_class_fields ctx clctx comp (e,p) =
 		let t = Function (List.map (fun (_,t) -> t_opt ctx p t) f.fargs , ret_opt ctx p f) in
 		if f.fname = snd clctx.path then begin
 			if f.ftype <> None then error (Custom "Constructor return type should not be specified") p;
+			if clctx.interface then error (Custom "Interface can't have a constructor") p;
 			match clctx.constructor with
 			| None -> clctx.constructor <- Some { f_name = f.fname;	f_type = t; f_static = IsMember; f_public = f.fpublic; f_pos = null_pos }
 			| Some _ -> error (Custom "Duplicate constructor") p;
