@@ -306,6 +306,7 @@ type shape_line_style = {
 	sls_color : color;
 	sls_flags : int option;
 	sls_fill : shape_fill_style option;
+	sls_miter : int option;
 }
 
 type shape_new_styles = {
@@ -533,6 +534,7 @@ type tag_data =
 	| TBitsLossless2 of bitmap_lossless
 	| TEditText of edit_text
 	| TClip of clip
+	| TProductInfo of unknown
 	| TFrameLabel of string * char option
 	| TSoundStreamHead2 of unknown
 	| TMorphShape of morph_shape
@@ -541,12 +543,16 @@ type tag_data =
 	| TDoInitAction of do_init_action
 	| TVideoStream of unknown
 	| TVideoFrame of unknown
+	| TDebugID of unknown
+	| TEnableDebugger2 of int * string
+	| TScriptLimits of int * int
 	| TSandbox of sandbox
 	| TPlaceObject3 of place_object
 	| TFontGlyphs of font_glyphs
 	| TTextInfo of unknown
 	| TFont3 of font3
 	| TF9Classes of f9class list
+	| TMetaData of string
 	| TActionScript3 of (int * string) option * As3.as3_tag
 	| TShape4 of shape
 	| TShape5 of int * string
